@@ -7,6 +7,7 @@ from django.dispatch import receiver
 from djangoldp.models import Model
 from django.utils.text import slugify
 from django.utils.translation import ugettext_lazy as _
+from importlib import import_module
 
 from djangoldp_community.permissions import CommunityPermissions, CommunityCirclePermissions, \
     CommunityProjectPermissions, CommunityJobPermissions, CommunityMembersPermissions, \
@@ -18,6 +19,19 @@ from djangoldp_project.models import Project
 from djangoldp_joboffer.models import JobOffer
 from rest_framework.exceptions import ValidationError
 
+djangoldp_modules = list(settings.DJANGOLDP_PACKAGES)
+community_fields = ['@id', 'name', 'profile', 'addresses', 'logo', 'allow_self_registration',\
+                             'projects', 'circles', 'members', 'joboffers']
+
+for dldp_module in djangoldp_modules:
+    try:
+        module_settings = import_module(dldp_module + '.settings')
+        module_community_nested_fields = module_settings.COMMUNITY_NESTED_FIELDS
+        community_fields += module_community_nested_fields
+    except:
+        pass
+
+
 class Community(Model):
     name = models.CharField(max_length=255, blank=True, null=True, help_text="Changing a community's name is highly discouraged")
     logo = models.URLField(blank=True, null=True)
@@ -40,8 +54,7 @@ class Community(Model):
         lookup_field = 'slug'
         container_path = "/communities/"
         ordering = ['slug']
-        serializer_fields = ['@id', 'name', 'profile', 'addresses', 'logo', 'allow_self_registration',\
-                             'projects', 'circles', 'members', 'joboffers']
+        serializer_fields = community_fields
         rdf_type = "sib:Community"
         depth = 1
 
