@@ -133,7 +133,7 @@ class CommunityMembersPermissions(CommunityPermissions):
             if 'slug' in resolved.kwargs and (resolved.url_name == "community-communitymember-list" or resolved.url_name == "community-detail"):
                 from djangoldp_community.models import Community
                 community = Community.objects.get(slug=resolved.kwargs['slug'])
-            elif resolved.url_name == "open-communities-community-list" and request.parent_id:
+            elif (resolved.url_name == "open-communities-community-list" or resolved.url_name == "community-list") and request.parent_id:
                 from djangoldp.models import Model
                 from django.conf import settings
                 community = Model.resolve_parent(request.parent_id.replace(settings.SITE_URL, ''))
